@@ -1,7 +1,7 @@
 matchit2full <- function(treat, X, data, distance, discarded,
                          verbose=FALSE, ...) { 
   if (!("optmatch" %in% .packages(all = TRUE)))
-    install.packages("optmatch", contriburl="http://www.stat.lsa.umich.edu/~bbh/optmatch")
+    install.packages("optmatch")
   require(optmatch)
   
   if(verbose)
